OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Toegevoegd aan de lijst met vertrouwde servers",
    "Server is already in the list of trusted servers." : "Server bestaat reeds in de lijst van vertrouwde servers.",
    "No server to federate with found" : "Geen server gevonden om mee te federeren",
    "Could not add server" : "Kon server niet toevoegen",
    "Federation" : "Federatie",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "Federatie maakt het mogelijk om te verbinden met andere vertrouwde servers om de gebuikersadministratie te delen.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Federatie maakt het mogelijk om te verbinden met vertrouwde servers en de gebuikersadministratie te delen. Zo kun je automatisch externe gebruikers toevoegen voor federatief delen.",
    "Trusted servers" : "Vertrouwde servers",
    "Add server automatically once a federated share was created successfully" : "Voeg server automatisch toe zodra een gefedereerde share succesvol gecreëerd is",
    "+ Add trusted server" : "+ Toevoegen vertrouwde server",
    "Trusted server" : "Vertrouwde server",
    "Add" : "Toevoegen"
},
"nplurals=2; plural=(n != 1);");
